import { OnInit, ElementRef, ChangeDetectorRef, OnChanges, SimpleChanges, TemplateRef } from '@angular/core';
import { CometChat } from '@cometchat-pro/chat';
import { EmojiKeyboardStyle, PopoverStyle, ActionSheetStyle, PreviewStyle } from 'my-cstom-package-lit';
import { Subscription } from 'rxjs';
import { localize, CometChatMessageComposerAction, AuxiliaryButtonAlignment, Placement } from 'uikit-resources-lerna';
import { MessageComposerStyle, StickersConfiguration, StickersStyle, CreatePollStyle, BaseStyle } from 'uikit-utils-lerna';
import { CometChatThemeService } from '../../CometChatTheme.service';
import 'uikit-utils-lerna';
import 'my-cstom-package-lit';
import * as i0 from "@angular/core";
/**
*
* CometChatMessageComposer is used to send message to user or group.
*
* @version 1.0.0
* @author CometChatTeam
* @copyright © 2022 CometChat Inc.
*
*/
export declare class CometChatMessageComposerComponent implements OnInit, OnChanges {
    private ref;
    private themeService;
    inputElementRef: ElementRef;
    inputRef: ElementRef;
    emojiButtonRef: ElementRef;
    actionSheetRef: ElementRef;
    stickerButtonRef: ElementRef;
    user: CometChat.User;
    group: CometChat.Group;
    disableSoundForMessages: boolean;
    customSoundForMessage: string;
    disableTypingEvents: boolean;
    text: string;
    placeholderText: string;
    headerView: TemplateRef<any>;
    onTextChange: (text: string) => void;
    attachmentIconURL: string;
    attachmentOptions: ((item: CometChat.User | CometChat.Group, composerId: ComposerId) => CometChatMessageComposerAction[]) | undefined;
    secondaryButtonView: TemplateRef<any>;
    auxilaryButtonView: TemplateRef<any>;
    auxiliaryButtonsAlignment: AuxiliaryButtonAlignment;
    sendButtonView: TemplateRef<any>;
    parentMessageId: number;
    hideLiveReaction: boolean;
    LiveReactionIconURL: string;
    messageComposerStyle: MessageComposerStyle;
    onSendButtonClick: ((message: CometChat.BaseMessage) => void) | undefined;
    onError: (error: any) => void;
    backdropStyle: BaseStyle;
    composerId: ComposerId;
    composerActions: CometChatMessageComposerAction[];
    showCreatePolls: boolean;
    showStickerKeyboard: boolean;
    showActionSheetItem: boolean;
    showPreview: boolean;
    editPreviewObject: CometChat.TextMessage;
    ccMessageEdit: Subscription;
    acceptHandlers: any;
    enableStickerKeyboard: boolean;
    stickerConfiguration: {
        id?: string;
        configuration?: StickersConfiguration;
    };
    closeIconURL: string;
    sendButtonStyle: any;
    liveReactionStyle: any;
    localize: typeof localize;
    emojiButtonStyle: any;
    emojiKeyboardStyle: EmojiKeyboardStyle;
    stickerKeyboardStyle: StickersStyle;
    messageInputStyle: any;
    previewStyle: PreviewStyle;
    createPollStyle: CreatePollStyle;
    storeTypingInterval: any;
    emojiPopover: PopoverStyle;
    stickerPopover: PopoverStyle;
    popoverStyle: PopoverStyle;
    sendButtonIconURL: string;
    emojiButtonIconURL: string;
    stickerButtonIconURL: string;
    actionsheetStyle: ActionSheetStyle;
    actions: CometChatMessageComposerAction[];
    messageText: string;
    attachmentButtonStyle: any;
    auxilaryPlacement: Placement;
    messageSending: boolean;
    messageToBeEdited: CometChat.TextMessage;
    showSendButton: boolean;
    showEmojiKeyboard: boolean;
    loggedInUser: CometChat.User | null;
    sendMessageOnEnter: (event: any) => void;
    messageInputChanged: (event: any) => void;
    appendEmoji: (event: any) => void;
    sendReaction(): void;
    openCreatePolls: () => void;
    closeCreatePolls: () => void;
    addAttachmentCallback(): void;
    subscribeToEvents(): void;
    openEditPreview(): void;
    unsubscribeToEvents(): void;
    constructor(ref: ChangeDetectorRef, themeService: CometChatThemeService);
    ngOnChanges(changes: SimpleChanges): void;
    customSendMethod(message: String): void;
    /**
       * @param  {String=""} textMsg
       */
    sendTextMessage(textMsg?: String): boolean;
    editMessage(): void;
    getReceiverDetails(): {
        receiverId: string;
        receiverType: string;
    };
    playAudio(): void;
    /**
       * @param  {} timer=null
       * @param  {string=""} metadata
       */
    startTyping(timer?: null, metadata?: string): void;
    handleActions: (event: any) => void;
    endTyping(metadata?: null): void;
    /**
     * @param  {File | CometChat.MediaMessage} messageInput
     * @param  {string} messageType
     */
    sendMediaMessage(messageInput: File, messageType: string): boolean;
    inputChangeHandler: (event: any) => void;
    sendSticker: (event: any) => void;
    /**
    * @param  {any} event
    */
    onVideoChange(event: any): boolean;
    /**
     * @param  {any} event
     */
    onAudioChange(event: any): boolean;
    /**
       * @param  {any} event
       */
    onImageChange(event: any): boolean;
    /**
     * @param  {any} event
     */
    onFileChange(event: any): boolean;
    openImagePicker: () => void;
    openFilePicker: () => void;
    openvideoPicker: () => void;
    openAudioPicker: () => void;
    openActionSheet: (event: any) => void;
    openEmojiKeyboard: (event: any) => void;
    openStickerKeyboard: (event: any) => void;
    closePopovers(): void;
    getComposerId(): ComposerId;
    ngOnInit(): void;
    setTheme(): void;
    setComposerStyle(): void;
    closePreview(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CometChatMessageComposerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CometChatMessageComposerComponent, "cometchat-message-composer", never, { "user": "user"; "group": "group"; "disableSoundForMessages": "disableSoundForMessages"; "customSoundForMessage": "customSoundForMessage"; "disableTypingEvents": "disableTypingEvents"; "text": "text"; "placeholderText": "placeholderText"; "headerView": "headerView"; "onTextChange": "onTextChange"; "attachmentIconURL": "attachmentIconURL"; "attachmentOptions": "attachmentOptions"; "secondaryButtonView": "secondaryButtonView"; "auxilaryButtonView": "auxilaryButtonView"; "auxiliaryButtonsAlignment": "auxiliaryButtonsAlignment"; "sendButtonView": "sendButtonView"; "parentMessageId": "parentMessageId"; "hideLiveReaction": "hideLiveReaction"; "LiveReactionIconURL": "LiveReactionIconURL"; "messageComposerStyle": "messageComposerStyle"; "onSendButtonClick": "onSendButtonClick"; "onError": "onError"; "backdropStyle": "backdropStyle"; }, {}, never, never>;
}
declare type ComposerId = {
    parentMessageId: number | null;
    user: string | null;
    group: string | null;
};
export {};
